==> xlniuxdata-vipgame-1.0.65-20160912.102500-59-sources.jar: com/xunlei/niux/data/vipgame/vo/mobileguild/MobileGuildSpread.java <==
package com.xunlei.niux.data.vipgame.vo.mobileguild;

import com.ferret.common.dao.annotation.Table;

/**
 * @author Administrator
 *
 */
@Table(tableName="mobileguildspread",pkFieldName="seqId",pkFieldAssign=false)
public class MobileGuildSpread {
	private Long seqId;
	private Long guildUserId;
	private String gameId;
	private String appVersion;

	private String  appSize;
	private String  platform;
	private String	inputTime;
	private String	downloadUrl;
	private boolean hasFinished;
	private boolean  hasChecked;
    private String channelId;
    private Long apkId;



	public Long getSeqId() {
		return seqId;
	}

	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}

	public Long getGuildUserId() {
		return guildUserId;
	}

	public void setGuildUserId(Long guildUserId) {
		this.guildUserId = guildUserId;
	}

	public String getGameId() {
		return gameId;
	}

	public void setGameId(String gameId) {
		this.gameId = gameId;
	}

	public String getAppVersion() {
		return appVersion;
	}

	public void setAppVersion(String appVersion) {
		this.appVersion = appVersion;
	}

	public String getAppSize() {
		return appSize;
	}

	public void setAppSize(String appSize) {
		this.appSize = appSize;
	}

	public String getPlatform() {
		return platform;
	}

	public void setPlatform(String platform) {
		this.platform = platform;
	}

	public String getInputTime() {
		return inputTime;
	}

	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}

	public String getDownloadUrl() {
		return downloadUrl;
	}

	public void setDownloadUrl(String downloadUrl) {
		this.downloadUrl = downloadUrl;
	}

	public boolean getHasFinished() {
		return hasFinished;
	}

	public void setHasFinished(boolean hasFinished) {
		this.hasFinished = hasFinished;
	}

    public String getChannelId(){
        return channelId;
    }

    public void setChannelId(String channelId){
        this.channelId = channelId;
    }

    public Long getApkId(){
        return apkId;
    }

    public void setApkId(Long apkId){
        this.apkId = apkId;
    }

	public boolean getHasChecked() {
		return hasChecked;
	}

	public void setHasChecked(boolean hasChecked) {
		this.hasChecked = hasChecked;
	}
}

==> xlniuxdata-vipgame-1.0.65-20161020.101143-18-sources.jar: com/xunlei/niux/data/vipgame/vo/mobileguild/MobileGuildSpread.java <==
package com.xunlei.niux.data.vipgame.vo.mobileguild;

import com.ferret.common.dao.annotation.Table;

/**
 * @author Administrator
 *
 */
@Table(tableName="mobileguildspread",pkFieldName="seqId",pkFieldAssign=false)
public class MobileGuildSpread {
	private Long seqId;
	private Long guildUserId;
	private String gameId;
	private String appVersion;

	private String  appSize;
	private String  platform;
	private String	inputTime;
	private String	downloadUrl;
	private Boolean hasFinished;
	private Boolean  hasChecked;
    private String channelId;
    private Long apkId;



	public Long getSeqId() {
		return seqId;
	}

	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}

	public Long getGuildUserId() {
		return guildUserId;
	}

	public void setGuildUserId(Long guildUserId) {
		this.guildUserId = guildUserId;
	}

	public String getGameId() {
		return gameId;
	}

	public void setGameId(String gameId) {
		this.gameId = gameId;
	}

	public String getAppVersion() {
		return appVersion;
	}

	public void setAppVersion(String appVersion) {
		this.appVersion = appVersion;
	}

	public String getAppSize() {
		return appSize;
	}

	public void setAppSize(String appSize) {
		this.appSize = appSize;
	}

	public String getPlatform() {
		return platform;
	}

	public void setPlatform(String platform) {
		this.platform = platform;
	}

	public String getInputTime() {
		return inputTime;
	}

	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}

	public String getDownloadUrl() {
		return downloadUrl;
	}

	public void setDownloadUrl(String downloadUrl) {
		this.downloadUrl = downloadUrl;
	}

	public Boolean getHasFinished() {
		return hasFinished;
	}

	public void setHasFinished(Boolean hasFinished) {
		this.hasFinished = hasFinished;
	}

	public Boolean getHasChecked() {
		return hasChecked;
	}

	public void setHasChecked(Boolean hasChecked) {
		this.hasChecked = hasChecked;
	}

	public String getChannelId(){
        return channelId;
    }

    public void setChannelId(String channelId){
        this.channelId = channelId;
    }

    public Long getApkId(){
        return apkId;
    }

    public void setApkId(Long apkId){
        this.apkId = apkId;
    }


}
